#!/bin/bash
# Copyright (c) Daniel Sheffield 2024 - 2025

ESSENTIAL_SYSTEM_SPECIFIC+=(
	awk
)

awk_strip_first_path_part_script () {
	cat <<'EOF'
{
    for (i=2; i<=NF; i++)
        printf "%s%s", $(i), (i<NF ? OFS : ORS)
}
EOF
}


awk_rw0_strip_first_path_part () {
	# NOTE: ./a/b/c -> a/b/c (null delimited)
	awk \
		-v FS='/' -v RS='\0' \
		-v OFS='/' -v ORS='\0' \
		"$(awk_strip_first_path_part_script)" \
	&& :

}

awk_r0_add_prefix () {
	# NOTE: some-string -> <prefix>some-string (null delimited)
	: "${2?awk_r0_add_prefix requires exactly two positional args}"
	: "${1:?awk_r0_add_prefix output record separator must be set and non-empty}"
	[ "${1:+DefinedNotEmpty}" == "DefinedNotEmpty" ]
	[ "${2+DefinedMaybeEmpty}" == "DefinedMaybeEmpty" ]
	awk \
		-v prefix="$2/" \
		-v RS='\0' \
		-v ORS="$1" \
	       '{print prefix $0}' \
	&& :
}

awk_r0_add_suffix () {
	# NOTE: some-string -> some-string<suffix> (null delimited)
	: "${2?awk_r0_add_suffix requires exactly two positional args}"
	: "${1:?awk_r0_add_suffix output record separator must be set and non-empty}"
	[ "${1:+DefinedNotEmpty}" == "DefinedNotEmpty" ]
	[ "${2+DefinedMaybeEmpty}" == "DefinedMaybeEmpty" ]
	awk \
		-v suffix="/$2" \
		-v RS='\0' \
		-v ORS="$1" \
	       '{print $0 suffix}' \
	&& :
}
