#!/bin/bash
# Copyright (c) Daniel Sheffield 2024 - 2025

LOG_ROOT="$HOME"/.local/var/log/shell

ESSENTIAL_GENERIC=(
	cat
	echo
	ls
	sort
	tee
)
ESSENTIAL_SYSTEM_SPECIFIC=(
	find
	head
	tail
	xargs
)
NONESSENTIAL=(
	iselect
	vipe
)

get_subprog () {
	# NOTE: for progams that wrap calls to others
	#       such as sudo, and time, the actual
	#       executable is not the first positional arg
	#
	# TODO: support su, runuser, runas et al
	# TODO: support time
	if [ "$PROG" = "sudo" ]
	then
		echo "$2" # naive - what if sudo is invoked with options?
	fi
}

check_deps () {
	for dep in "${ESSENTIAL_GENERIC[@]}" "${ESSENTIAL_SYSTEM_SPECIFIC[@]}"
	do
		which "$dep" || {
			echo "essential dependencies missing: $dep" >&3
			exit 1
		}
	done
	for dep in "${NONESSENTIAL[@]}"
	do
		which "$dep" || echo "non-essential dependencies missing: $dep" >&2
	done
}
